@@ -23,8 +23,6 @@ from astropy import constants as const
 # matplotlib
 import matplotlib.pyplot as plt
 from matplotlib.ticker import FormatStrFormatter, NullFormatter
-plt.rcParams['figure.dpi'] = 300
-plt.rcParams['savefig.dpi'] = 300
 
 # astroquery
 from astroquery.alma import Alma
@@ -241,13 +239,13 @@ def catalog(target_df, search_radius=1., point=True, public=True, published=None
     ----------
     target_df : pandas.DataFrame
          Source names and coordinates.
+
          Index:
             RangeIndex
          Columns:
             Name: Name, dtype: str, description: target name (can be numbers or dummy names)
             Name: RAJ2000, dtype: float64, description: right ascension in degrees (ICRS)
             Name: DEJ2000, dtype: float64, description: declination in degrees (ICRS)
-        
     search_radius : float, optional
          (Default value = 1. arcmin)
          Search radius (in arcmin) around the source coordinates.
@@ -1366,7 +1364,12 @@ def download_data(observations, fitsonly=False, dryrun=False, print_urls=False,
     print("Total number of Member OUSs to download = {}".format(len(uids_list)))
     print("Selected Member OUSs: {}".format(uids_list.tolist()))
     print("Number of files to download = {}".format(dl_files))
-    print("Needed disk space = {:.1f} GB".format(dl_size))
+    if dl_size > 1000.:
+        print("Needed disk space = {:.1f} TB".format(dl_size/1000.))
+    elif dl_size < 1.:
+        print("Needed disk space = {:.1f} MB".format(dl_size*1000.))
+    else:
+        print("Needed disk space = {:.1f} GB".format(dl_size))
     if print_urls:
         print("File URLs to download = {}".format("\n".join(dl_link_list)))
     print("--------------------------------")
